Class: Google::Apis::FcmdataV1beta1::GoogleFirebaseFcmDataV1beta1ProxyNotificationInsightPercents

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/fcmdata_v1beta1/classes.rb,
lib/google/apis/fcmdata_v1beta1/representations.rb,
lib/google/apis/fcmdata_v1beta1/representations.rb

Overview

Additional information about proxy notification delivery. All percentages are calculated with countNotificationsAccepted as the denominator.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleFirebaseFcmDataV1beta1ProxyNotificationInsightPercents

Returns a new instance of GoogleFirebaseFcmDataV1beta1ProxyNotificationInsightPercents.



364
365
366
# File 'lib/google/apis/fcmdata_v1beta1/classes.rb', line 364

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#failedFloat

The percentage of accepted notifications that failed to be proxied. This is usually caused by exceptions that occurred while calling notifyAsPackage. Corresponds to the JSON property failed

Returns:

  • (Float)


332
333
334
# File 'lib/google/apis/fcmdata_v1beta1/classes.rb', line 332

def failed
  @failed
end

#proxiedFloat

The percentage of accepted notifications that were successfully proxied by Google Play services. Corresponds to the JSON property proxied

Returns:

  • (Float)


338
339
340
# File 'lib/google/apis/fcmdata_v1beta1/classes.rb', line 338

def proxied
  @proxied
end

#skipped_not_throttledFloat

The percentage of accepted notifications that were skipped because the messages were not throttled. Corresponds to the JSON property skippedNotThrottled

Returns:

  • (Float)


344
345
346
# File 'lib/google/apis/fcmdata_v1beta1/classes.rb', line 344

def skipped_not_throttled
  @skipped_not_throttled
end

#skipped_opted_outFloat

The percentage of accepted notifications that were skipped because the app disallowed these messages to be proxied. Corresponds to the JSON property skippedOptedOut

Returns:

  • (Float)


350
351
352
# File 'lib/google/apis/fcmdata_v1beta1/classes.rb', line 350

def skipped_opted_out
  @skipped_opted_out
end

#skipped_unconfiguredFloat

The percentage of accepted notifications that were skipped because configurations required for notifications to be proxied were missing. Corresponds to the JSON property skippedUnconfigured

Returns:

  • (Float)


356
357
358
# File 'lib/google/apis/fcmdata_v1beta1/classes.rb', line 356

def skipped_unconfigured
  @skipped_unconfigured
end

#skipped_unsupportedFloat

The percentage of accepted notifications that were skipped because proxy notification is unsupported for the recipient. Corresponds to the JSON property skippedUnsupported

Returns:

  • (Float)


362
363
364
# File 'lib/google/apis/fcmdata_v1beta1/classes.rb', line 362

def skipped_unsupported
  @skipped_unsupported
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



369
370
371
372
373
374
375
376
# File 'lib/google/apis/fcmdata_v1beta1/classes.rb', line 369

def update!(**args)
  @failed = args[:failed] if args.key?(:failed)
  @proxied = args[:proxied] if args.key?(:proxied)
  @skipped_not_throttled = args[:skipped_not_throttled] if args.key?(:skipped_not_throttled)
  @skipped_opted_out = args[:skipped_opted_out] if args.key?(:skipped_opted_out)
  @skipped_unconfigured = args[:skipped_unconfigured] if args.key?(:skipped_unconfigured)
  @skipped_unsupported = args[:skipped_unsupported] if args.key?(:skipped_unsupported)
end